@@ -4,7 +4,7 @@ Catmandu::Exporter::MARC::ALEPHSEQ - Exporter for MARC records to Ex Libris' Ale
 
 =head1 SYNOPSIS
 
-    # From the command line 
+    # From the command line
     $ catmandu convert MARC to MARC --type ALEPHSEQ < /foo/data.mrc
 
     # From Perl
@@ -16,33 +16,36 @@ Catmandu::Exporter::MARC::ALEPHSEQ - Exporter for MARC records to Ex Libris' Ale
     $exporter->add($importer);
     $exporter->commit;
 
+=head1 CONFIGURATION
+
+=over
+
+=item file
+
+Write output to a local file given by its path or file handle.  Alternatively a
+scalar reference can be passed to write to a string and a code reference can be
+used to write to a callback function.
+
+=item fh
+
+Write the output to an L<IO::Handle>. If not specified,
+L<Catmandu::Util::io|Catmandu::Util/IO-functions> is used to create the output
+handle from the C<file> argument or by using STDOUT.
+
+=item fix
+
+An ARRAY of one or more fixes or file scripts to be applied to exported items.
+
+=item encoding
+
+Binmode of the output stream C<fh>. Set to "C<:utf8>" by default.
+
+=back
+
 =head1 METHODS
 
-=head2 new(file => $file , %opts)
-
-Create a new L<Catmandu::Exporter> to serialize MARC record into Aleph sequential. Provide the path
-of a $file to write exported records to. Optionally the following parameters can be
-specified:
-
-	record : the key containing the marc record (default: 'record')
-	record_format : optionally set to 'MARC-in-JSON' when the input format is in MARC-in-JSON
-	skip_empty_subfields : skip fields which don't contain any data (default: false)
-
-=head1 INHERTED METHODS
-
-=head2 count
-
-=head2 add($hashref)
-
-=head2 add_many($array)
-
-=head2 add_many($iterator)
-
-=head2 add_many(sub {})
-
-=head2 ...
-
-All the L<Catmandu::Exporter> methods are inherited.
+See L<Catmandu::Exporter>, L<Catmandu::Addable>, L<Catmandu::Fixable>,
+L<Catmandu::Counter>, and L<Catmandu::Logger> for a full list of methods.
 
 =head1 SEE ALSO
 
@@ -55,7 +58,7 @@ use Catmandu::Util qw(xml_escape is_different :array :is);
 use List::Util;
 use Moo;
 
-our $VERSION = '0.218';
+our $VERSION = '0.219';
 
 with 'Catmandu::Exporter', 'Catmandu::Exporter::MARC::Base';
 
@@ -66,18 +69,18 @@ has skip_empty_subfields => (is => 'ro' , default => sub { 0 });
 sub add {
     my ($self,$data) = @_;
 
-    if ($self->record_format eq 'MARC-in-JSON') { 
+    if ($self->record_format eq 'MARC-in-JSON') {
         $data = $self->_json_to_raw($data);
     }
 
     my $_id    = sprintf("%-9.9d", $data->{_id} // 0);
-	my $record = $data->{$self->record};  
+	my $record = $data->{$self->record};
 
     my @lines = ();
 
     for my $field (@$record) {
         my ($tag,$ind1,$ind2,@data) = @$field;
-    
+
         $ind1 = ' ' unless defined $ind1;
         $ind2 = ' ' unless defined $ind2;
 
@@ -85,10 +88,10 @@ sub add {
 
         next if $#data == -1;
 
-        # Joins are faster than perl string concatenation 
+        # Joins are faster than perl string concatenation
         if (index($tag,'FMT') == 0 || index($tag,'00') == 0) {
             push @lines , join('', $_id , ' ' , $tag , $ind1 , $ind2 , ' L ', $data[1] );
-        } 
+        }
         elsif (index($tag,'LDR') == 0) {
             my $ldr = $data[1];
             $ldr =~ s/ /^/og;
@@ -114,4 +117,4 @@ sub commit {
 	$self->fh->flush;
 }
 
-1;
\ No newline at end of file
+1;
