@@ -5,7 +5,9 @@ use Catmandu::Util qw(:is);
 use Moo;
 use Catmandu::Fix::Has;
 
-our $VERSION = '0.218';
+with 'Catmandu::Fix::Inlineable';
+
+our $VERSION = '0.219';
 
 has record  => (fix_opt => 1);
 has reverse => (fix_opt => 1);
@@ -34,7 +36,7 @@ sub _json_record {
             next unless is_hash_ref($field);
 
             my ($tag) = keys %$field;
-            my $val   = $field->{$tag}; 
+            my $val   = $field->{$tag};
 
             if ($tag eq 'FMT' || substr($tag, 0, 2) eq '00') {
                push @$record , [ $tag, undef, undef, '_', $val ],
@@ -118,8 +120,7 @@ Catmandu::Fix::marc_in_json - transform a Catmandu MARC record into MARC-in-JSON
 
 =head1 DESCRIPTION
 
-Read our Wiki pages at L<https://github.com/LibreCat/Catmandu/wiki/Fixes> for a complete
-overview of the Fix language.
+Convert the MARC record into MARC-in-JSON format
 
 =head1 SEE ALSO
 
