@@ -6,7 +6,9 @@ use Carp qw(confess);
 use Moo;
 use Catmandu::Fix::Has;
 
-our $VERSION = '0.218';
+with 'Catmandu::Fix::Base';
+
+our $VERSION = '0.219';
 
 has marc_path      => (fix_arg => 1);
 has value          => (fix_arg => 1);
@@ -92,8 +94,8 @@ sub emit {
                 }
                 else {
                     $perl  .=        "${var}->[${i}+1] = ${value};";
-                } 
-                                
+                }
+
                 $perl .=             "${found} = 1;";
                 $perl .=        "}".
                             "}";
@@ -112,7 +114,7 @@ sub emit {
         $perl .= "} elsif (defined ${var}->[5] && ${var}->[5] eq '_') {";
         $perl .= $set_subfields->(5);
         $perl .= "} else {";
-            
+
         $perl .= $set_subfields->(3);
         $perl .= "}";
 
@@ -144,8 +146,7 @@ Catmandu::Fix::marc_set - set a marc value of one (sub)field to a new value
 
 =head1 DESCRIPTION
 
-Read our Wiki pages at L<https://github.com/LibreCat/Catmandu/wiki/Fixes> for a complete
-overview of the Fix language.
+Set the value of a MARC subfield to a new value.
 
 =head1 SEE ALSO
 
@@ -153,4 +154,4 @@ L<Catmandu::Fix>
 
 =cut
 
-1;
\ No newline at end of file
+1;
