@@ -3,7 +3,20 @@ package Catmandu::Importer::MARC::Decoder;
 use Catmandu::Sane;
 use Moo;
 
-our $VERSION = '0.218';
+our $VERSION = '0.219';
+
+sub fake_marc_file {
+    my ($self,$fh,$class) = @_;
+
+    my $obj = {
+        filename    => scalar($fh),
+        fh          => $fh,
+        recnum      => 0,
+        warnings    => [],
+    };
+
+    return( bless $obj , $class );
+}
 
 sub decode {
     my ($self, $record, $id) = @_;
@@ -46,4 +59,4 @@ sub decode {
     return { _id => $sysid , record => \@result };
 }
 
-1;
\ No newline at end of file
+1;
