@@ -4,7 +4,7 @@ Catmandu::Importer::MARC::MiJ - Package that imports MARC-in-JSON records
 
 =head1 SYNOPSIS
 
-    # From the command line 
+    # From the command line
     $ catmandu convert MARC --type MiJ --fix "marc_map('245a','title')" < /foo/data.js
 
     # From perl
@@ -41,7 +41,7 @@ id attribute specifying the source of the system identifer '_id' field (e.g. '00
 
 =head2 ...
 
-Every Catmandu::Importer is a Catmandu::Iterable all its methods are inherited. 
+Every Catmandu::Importer is a Catmandu::Iterable all its methods are inherited.
 
 =head1 SEE ALSO
 
@@ -55,14 +55,14 @@ use MARC::Record;
 use Catmandu::Importer::MARC::Decoder;
 use MARC::File::MiJ;
 
-our $VERSION = '0.218';
+our $VERSION = '0.219';
 
 with 'Catmandu::Importer';
 
 has id        => (is => 'ro' , default => sub { '001' });
 has decoder   => (
     is   => 'ro',
-    lazy => 1 , 
+    lazy => 1 ,
     builder => sub {
         Catmandu::Importer::MARC::Decoder->new;
     } );
@@ -70,9 +70,12 @@ has decoder   => (
 sub generator {
     my ($self) = @_;
     my $file = MARC::File::MiJ->in($self->file);
+
+    # MARC::File doesn't provide support for inline files
+    $file = $self->decoder->fake_marc_file($self->fh,'MARC::File::MiJ') unless $file;
     sub  {
       $self->decoder->decode($file->next(),$self->id);
     }
 }
 
-1;
\ No newline at end of file
+1;
