@@ -4,7 +4,7 @@ Catmandu::Importer::MARC::MicroLIF - Package that imports MicroLIF records
 
 =head1 SYNOPSIS
 
-    # From the command line 
+    # From the command line
     $ catmandu convert MARC --type MicroLIF --fix "marc_map('245a','title')" < /foo/data.lif
 
     # From perl
@@ -26,26 +26,42 @@ Catmandu::Importer::MARC::MicroLIF - Package that imports MicroLIF records
         printf "title: %s\n" , $item->{title};
     });
 
+=head1 CONFIGURATION
+
+=over
+
+=item id
+
+The MARC field which contains the system id (default: 001)
+
+=item file
+
+Read input from a local file given by its path. Alternatively a scalar
+reference can be passed to read from a string.
+
+=item fh
+
+Read input from an L<IO::Handle>. If not specified, L<Catmandu::Util::io> is used to
+create the input stream from the C<file> argument or by using STDIN.
+
+=item encoding
+
+Binmode of the input stream C<fh>. Set to C<:utf8> by default.
+
+=item fix
+
+An ARRAY of one or more fixes or file scripts to be applied to imported items.
+
+=back
+
 =head1 METHODS
 
-=head2 new(file => $file , fh => $fh , id => $field)
-
-Parse a file or a filehandle into a L<Catmandu::Iterable>. Optionally provide an
-id attribute specifying the source of the system identifer '_id' field (e.g. '001').
-
-=head1 INHERTED METHODS
-
-=head2 count
-
-=head2 each(&callback)
-
-=head2 ...
-
-Every Catmandu::Importer is a Catmandu::Iterable all its methods are inherited. 
+Every Catmandu::Importer is a Catmandu::Iterable all its methods are inherited.
 
 =head1 SEE ALSO
 
-L<MARC::File::MicroLIF>
+L<Catmandu::Importer>,
+L<Catmandu::Iterable>
 
 =cut
 package Catmandu::Importer::MARC::MicroLIF;
@@ -54,14 +70,14 @@ use Moo;
 use MARC::File::MicroLIF;
 use Catmandu::Importer::MARC::Decoder;
 
-our $VERSION = '0.218';
+our $VERSION = '0.219';
 
 with 'Catmandu::Importer';
 
 has id        => (is => 'ro' , default => sub { '001' });
 has decoder   => (
     is   => 'ro',
-    lazy => 1 , 
+    lazy => 1 ,
     builder => sub {
         Catmandu::Importer::MARC::Decoder->new;
     } );
@@ -69,9 +85,11 @@ has decoder   => (
 sub generator {
     my ($self) = @_;
     my $file = MARC::File::MicroLIF->in($self->fh);
+    # MARC::File doesn't provide support for inline files
+    $file = $self->decoder->fake_marc_file($self->fh,'MARC::File::MicroLIF') unless $file;
     sub  {
       $self->decoder->decode($file->next(),$self->id);
     }
 }
 
-1;
\ No newline at end of file
+1;
